@@ -1,20 +1,21 @@
 // ActivityMonitor.cc --- ActivityMonitor
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2001 - 2007 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2007 Ray Satiro <raysatiro@yahoo.com>
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2, or (at your option)
 // any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: ActivityMonitor.cc 1087 2006-10-01 18:40:08Z dotsphinx $";
+static const char rcsid[] = "$Id: ActivityMonitor.cc 1326 2007-09-10 20:43:47Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -45,7 +46,11 @@ static const char rcsid[] = "$Id: ActivityMonitor.cc 1087 2006-10-01 18:40:08Z d
 #if defined(HAVE_X)
 #include "X11InputMonitor.hh"
 #elif defined(WIN32)
+#include "CoreFactory.hh"
+#include "IConfigurator.hh"
 #include "W32InputMonitor.hh"
+#include "W32AlternateMonitor.hh"
+#include "W32LowLevelMonitor.hh"
 #endif
 
 
@@ -62,13 +67,13 @@ ActivityMonitor::ActivityMonitor(const char *display) :
   TRACE_ENTER("ActivityMonitor::ActivityMonitor");
 
   (void) display;
-  
+
   first_action_time.tv_sec = 0;
   first_action_time.tv_usec = 0;
 
   last_action_time.tv_sec = 0;
   last_action_time.tv_usec = 0;
-  
+
   noise_threshold.tv_sec = 1;
   noise_threshold.tv_usec = 0;
 
@@ -80,7 +85,7 @@ ActivityMonitor::ActivityMonitor(const char *display) :
 
   last_mouse_time.tv_sec = 0;
   last_mouse_time.tv_usec = 0;
-  
+
   total_mouse_time.tv_sec = 0;
   total_mouse_time.tv_usec = 0;
 
@@ -88,14 +93,161 @@ ActivityMonitor::ActivityMonitor(const char *display) :
   statistics.total_click_movement = 0;
   statistics.total_clicks = 0;
   statistics.total_keystrokes = 0;
-  
-#if defined(HAVE_X)
-  input_monitor = new X11InputMonitor(display);
-#elif defined(WIN32)
-  input_monitor = new W32InputMonitor();
-#endif
 
-  input_monitor->init(this);
+#if defined(HAVE_X)
+
+  input_monitor = new X11InputMonitor(display);
+  input_monitor->init( this );
+
+#elif defined(WIN32)
+
+  bool initialized = false;
+  string monitor_method;
+  
+  CoreFactory::get_configurator()->get_value_default("advanced/monitor", &monitor_method, "normal");
+  
+  if (monitor_method == "lowlevel")
+    {
+      input_monitor = new W32LowLevelMonitor();
+      initialized = input_monitor->init(this);
+      
+      if (!initialized)
+        {
+          int ret = MessageBoxA( NULL, 
+             "Workrave's alternate low-level activity monitor failed to initialize.\n\n"
+             "Click 'OK' to try using the regular activity monitor instead.\n",
+             "Workrave: Debug Message", 
+             MB_OKCANCEL | MB_ICONERROR | MB_TOPMOST );
+              
+          delete input_monitor;
+          if( ret != IDOK )
+            {
+              delete CoreFactory::get_configurator();
+              TRACE_EXIT();
+              exit(0);
+            }
+          
+          monitor_method = "normal";
+          CoreFactory::get_configurator()->set_value("advanced/monitor", monitor_method);
+          CoreFactory::get_configurator()->save();
+        }
+    }
+  
+
+  if (monitor_method == "nohook")
+    {
+      input_monitor = new W32AlternateMonitor();
+      initialized = input_monitor->init(this);
+
+      if (!initialized)
+        {
+          int ret = MessageBoxA( NULL, 
+             "Workrave's alternate activity monitor failed to initialize.\n\n"
+             "Click 'OK' to try using the regular activity monitor instead.\n",
+             "Workrave: Debug Message", 
+             MB_OKCANCEL | MB_ICONERROR | MB_TOPMOST );
+              
+          delete input_monitor;
+          if( ret != IDOK )
+            {
+              delete CoreFactory::get_configurator();
+              TRACE_EXIT();
+              exit(0);
+            }
+          
+          monitor_method = "normal";
+          CoreFactory::get_configurator()->set_value("advanced/monitor", monitor_method);
+          CoreFactory::get_configurator()->save();
+        }
+    }
+
+  if (monitor_method == "normal" || !initialized)
+    {
+      input_monitor = new W32InputMonitor();
+      initialized = input_monitor->init(this);
+
+      if (!initialized)
+        {
+          int ret = MessageBoxA( NULL,
+              "Workrave must be able to monitor certain system "
+              "events in order to determine when you are idle.\n\n"
+
+              "An attempt was made to hook into your system, but it "
+              "was unsuccessful.\n\n"
+
+              "You might have system safety software that blocks "
+              "Workrave from installing global hooks on your system.\n\n"
+
+              "You can instead run Workrave using the alternate monitor, "
+              "which doesn't require global hooks.\n\n"
+
+              "Click 'OK' to run the alternate monitor, or 'Cancel' to exit.\n",
+
+              "Workrave: Debug Message",
+              MB_OKCANCEL | MB_ICONSTOP | MB_TOPMOST );
+
+          /*
+          We want the current input monitor destructor called
+          at this point, after the user responds to the messagebox.
+          This way, if debugging, debug output can be viewed before
+          the user responds to the message box.
+          */
+          delete input_monitor;
+
+          if( ret == IDCANCEL )
+            {
+              delete CoreFactory::get_configurator();
+              TRACE_EXIT();
+              exit( 0 );
+            }
+          else
+            {
+              monitor_method = "nohook";
+              CoreFactory::get_configurator()->set_value("advanced/monitor", monitor_method);
+              CoreFactory::get_configurator()->save();
+            }
+        }
+    }
+
+// Final try:
+  if (monitor_method == "nohook" || !initialized)
+    {
+      input_monitor = new W32AlternateMonitor();
+      initialized = input_monitor->init(this);
+
+      if (!initialized)
+        {
+          MessageBoxA( NULL,
+                "Workrave must be able to monitor certain system "
+                "events in order to determine when you are idle.\n\n"
+                
+                "Attempts were made to monitor your system, "
+                "but they were unsuccessful.\n\n"
+                
+                "Workrave has reset itself to use its default monitor."
+                "Please run Workrave again. If you see this message "
+                "again, please file a bug report:\n\n"
+                
+                "http://issues.workrave.org/\n\n"
+                
+                "Workrave must exit now.\n",
+                "Workrave: Debug Message",
+                MB_OK );
+          
+          delete input_monitor;
+          
+          monitor_method = "normal";
+          CoreFactory::get_configurator()->set_value("advanced/monitor", monitor_method);
+          CoreFactory::get_configurator()->save();
+          
+          delete CoreFactory::get_configurator();
+          
+          TRACE_EXIT();
+          exit( 0 );
+        }
+    }
+  
+#endif
 
   TRACE_EXIT();
 }
@@ -110,7 +262,7 @@ ActivityMonitor::~ActivityMonitor()
 
   TRACE_EXIT();
 }
- 
+
 
 //! Terminates the monitor.
 void
@@ -265,8 +417,8 @@ ActivityMonitor::shift_time(int delta)
   struct timeval d;
 
   lock.lock();
-  tvSETTIME(d, delta, 0)
-    
+  tvSETTIME(d, delta, 0);
+
   if (!tvTIMEEQ0(last_action_time))
     tvADDTIME(last_action_time, last_action_time, d);
 
@@ -294,7 +446,7 @@ void
 ActivityMonitor::action_notify()
 {
   lock.lock();
-  
+
   struct timeval now;
   gettimeofday(&now, NULL);
 
@@ -315,11 +467,11 @@ ActivityMonitor::action_notify()
           }
       }
       break;
-      
+
     case ACTIVITY_NOISE:
       {
         struct timeval tv;
-        
+
         tvSUBTIME(tv, now, last_action_time);
         if (tvTIMEGT(tv, noise_threshold))
           {
@@ -357,26 +509,26 @@ ActivityMonitor::mouse_notify(int x, int y, int wheel_delta)
   const int delta_y = y - prev_y;
   prev_x = x;
   prev_y = y;
-  
+
   if (abs(delta_x) >= sensitivity || abs(delta_y) >= sensitivity
       || wheel_delta != 0 || button_is_pressed)
     {
       statistics.total_movement += int(sqrt((double)(delta_x * delta_x + delta_y * delta_y)));
-      
+
       action_notify();
 
       struct timeval now, tv;
 
       gettimeofday(&now, NULL);
       tvSUBTIME(tv, now, last_mouse_time);
-      
+
       if (!tvTIMEEQ0(last_mouse_time) && tv.tv_sec < 1 && tv.tv_sec >= 0 && tv.tv_usec >= 0)
         {
-          tvADDTIME(total_mouse_time, total_mouse_time, tv)
+          tvADDTIME(total_mouse_time, total_mouse_time, tv);
         }
 
       last_mouse_time = now;
-      
+
     }
   lock.unlock();
 }
@@ -393,21 +545,21 @@ ActivityMonitor::button_notify(int button_mask, bool is_press)
     {
       int delta_x = click_x - prev_x;
       int delta_y = click_y - prev_y;
-     
+
       statistics.total_click_movement += int(sqrt((double)(delta_x * delta_x + delta_y * delta_y)));
     }
-  
+
   click_x = prev_x;
   click_y = prev_y;
 
   button_is_pressed = is_press;
-  
+
   if (is_press)
     {
       action_notify();
       statistics.total_clicks++;
     }
-  
+
   lock.unlock();
 }
 
@@ -418,7 +570,7 @@ ActivityMonitor::keyboard_notify(int key_code, int modifier)
 {
   (void)key_code;
   (void)modifier;
-  
+
   lock.lock();
   action_notify();
   statistics.total_keystrokes++;
