@@ -1,20 +1,20 @@
 // Thread.cc --- Thread class
 //
-// Copyright (C) 2001, 2002, 2003 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2, or (at your option)
 // any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: Thread.cc 687 2004-01-28 12:16:46Z dotsphinx $";
+static const char rcsid[] = "$Id: Thread.cc 1298 2007-08-30 14:18:04Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -50,6 +50,7 @@ Thread::Thread(Runnable *t)
 {
   target = t;
   running = false;
+  auto_delete = true;
 }
 
 
