@@ -1,19 +1,19 @@
-// Display.cc
+// System.cc
 //
-// Copyright (C) 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
+// Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2, or (at your option)
 // any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-// $Id: System.cc 1090 2006-10-01 20:49:47Z dotsphinx $
+// $Id: System.cc 1331 2007-09-14 17:22:10Z rcaelers $
 //
 
 #ifdef HAVE_CONFIG_H
@@ -25,6 +25,7 @@
 #endif
 
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 #include <strings.h>
 
@@ -42,41 +43,44 @@
 #include <shlobj.h>
 #include "harpoon.h"
 
+#include "CoreFactory.hh"
+#include "IConfigurator.hh"
+
 /* MinGW does not have this one yet */
 #undef INTERFACE
 #define INTERFACE IShellDispatch
 DECLARE_INTERFACE_(IShellDispatch, IUnknown)
 {
-	STDMETHOD(QueryInterface)(THIS_ REFIID,PVOID*) PURE;
-	STDMETHOD_(ULONG,AddRef)(THIS) PURE;
-	STDMETHOD_(ULONG,Release)(THIS) PURE;
-	STDMETHOD_(ULONG,dummy1)(THIS) PURE;
-	STDMETHOD_(ULONG,dummy2)(THIS) PURE;
-	STDMETHOD_(ULONG,dummy3)(THIS) PURE;
-	STDMETHOD_(ULONG,dummy4)(THIS) PURE;
-	STDMETHOD_(ULONG,dummy5)(THIS) PURE;
-	STDMETHOD_(ULONG,dummy6)(THIS) PURE;
-	STDMETHOD_(ULONG,dummy7)(THIS) PURE;
-	STDMETHOD_(ULONG,dummy8)(THIS) PURE;
-	STDMETHOD_(ULONG,dummy9)(THIS) PURE;
-	STDMETHOD_(ULONG,dummya)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyb)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyc)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyd)(THIS) PURE;
-	STDMETHOD_(ULONG,dummye)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyf)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyg)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyh)(THIS) PURE;
+  STDMETHOD(QueryInterface)(THIS_ REFIID,PVOID*) PURE;
+  STDMETHOD_(ULONG,AddRef)(THIS) PURE;
+  STDMETHOD_(ULONG,Release)(THIS) PURE;
+  STDMETHOD_(ULONG,dummy1)(THIS) PURE;
+  STDMETHOD_(ULONG,dummy2)(THIS) PURE;
+  STDMETHOD_(ULONG,dummy3)(THIS) PURE;
+  STDMETHOD_(ULONG,dummy4)(THIS) PURE;
+  STDMETHOD_(ULONG,dummy5)(THIS) PURE;
+  STDMETHOD_(ULONG,dummy6)(THIS) PURE;
+  STDMETHOD_(ULONG,dummy7)(THIS) PURE;
+  STDMETHOD_(ULONG,dummy8)(THIS) PURE;
+  STDMETHOD_(ULONG,dummy9)(THIS) PURE;
+  STDMETHOD_(ULONG,dummya)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyb)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyc)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyd)(THIS) PURE;
+  STDMETHOD_(ULONG,dummye)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyf)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyg)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyh)(THIS) PURE;
         STDMETHOD(ShutdownWindows)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyi)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyj)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyk)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyl)(THIS) PURE;
-	STDMETHOD_(ULONG,dummym)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyn)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyo)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyp)(THIS) PURE;
-	STDMETHOD_(ULONG,dummyq)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyi)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyj)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyk)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyl)(THIS) PURE;
+  STDMETHOD_(ULONG,dummym)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyn)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyo)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyp)(THIS) PURE;
+  STDMETHOD_(ULONG,dummyq)(THIS) PURE;
 END_INTERFACE
 };
 typedef IShellDispatch *LPSHELLDISPATCH;
@@ -98,8 +102,9 @@ const GUID CLSID_Shell =
 
 #if defined(HAVE_X)
 
-gchar *System::xlock = NULL;
 bool System::kde = false;
+bool System::lockable = false;
+std::string System::lock_display;
 
 #elif defined(WIN32)
 
@@ -114,7 +119,7 @@ System::is_lockable()
 {
   bool ret;
 #if defined(HAVE_X)
-  ret = xlock != NULL;
+  ret = lockable;
 #elif defined(WIN32)
   ret = lock_func != NULL;
 #else
@@ -123,6 +128,36 @@ System::is_lockable()
   return ret;
 }
 
+#ifdef HAVE_X
+static bool
+invoke(const gchar* command, bool async = false)
+{
+  GError *error = NULL;
+
+  if(!async)
+    {
+      // synchronised call
+      gint exit_code;
+      if (!g_spawn_command_line_sync(command, NULL, NULL, &exit_code, &error) )
+        {
+          g_error_free(error);
+          return false;
+        }
+      return WEXITSTATUS(exit_code) == 0;
+    }
+  else
+    {
+      // asynchronous call
+      if (!g_spawn_command_line_async(command, &error) )
+        {
+          g_error_free(error);
+          return false;
+        }
+      return true;
+    }
+}
+#endif
+
 void
 System::lock()
 {
@@ -130,13 +165,39 @@ System::lock()
   if (is_lockable())
     {
 #if defined(HAVE_X)
-      GString *cmd = g_string_new(xlock);
-      cmd = g_string_append_c(cmd, '&');
-      system(cmd->str);
-      g_string_free(cmd, true);
+      gchar *program = NULL, *cmd = NULL;
+      if (is_kde() && (program = g_find_program_in_path("kdesktop_lock")))
+        {
+          cmd = g_strdup_printf("%s --display \"%s\" --forcelock",
+                                program, lock_display.c_str() );
+          invoke(cmd, true);
+          goto end;
+        }
+      if ((program = g_find_program_in_path("xscreensaver-command")))
+        {
+          cmd = g_strdup_printf("%s --display \"%s\" -lock",
+                                program, lock_display.c_str() );
+          if(invoke(cmd, false) )
+            goto end;
+        }
+      if ((program = g_find_program_in_path("gnome-screensaver-command")))
+        {
+          cmd = g_strdup_printf("%s --lock", program);
+          if(invoke(cmd, false) )
+            goto end;
+        }
+      if ((program = g_find_program_in_path("xlock")))
+        {
+          cmd = g_strdup_printf("%s -display \"%s\"",
+                                program, lock_display.c_str() );
+          invoke(cmd, true);
+        }
+end:  // cleanup of created strings, jump to avoid duplication
+      g_free(program);
+      g_free(cmd);
 #elif defined(WIN32)
       (*lock_func)();
-#endif  
+#endif
     }
   TRACE_EXIT();
 }
@@ -161,7 +222,7 @@ System::shutdown()
 #if defined(HAVE_X)
 #elif defined(WIN32)
   shutdown_helper(true);
-#endif  
+#endif
 }
 
 #ifdef WIN32
@@ -196,31 +257,22 @@ System::init(
   TRACE_ENTER("System::init");
 #if defined(HAVE_X)
   init_kde(display);
-  gchar *lock = NULL;
-  if (is_kde() && (lock = g_find_program_in_path("kdesktop_lock")))
+ 
+  gchar *program;
+  if (is_kde() && (program = g_find_program_in_path("kdesktop_lock")) != NULL)
+    lockable = true;
+  else if ((program = g_find_program_in_path("xscreensaver-command")) != NULL)
+    lockable = true;
+  else if ((program = g_find_program_in_path("gnome-screensaver-command")) != NULL)
+    lockable = true;
+  else if ((program = g_find_program_in_path("xlock")) != NULL)
+    lockable = true;
+ 
+  if (lockable)
     {
-      xlock = g_strdup_printf("%s --display \"%s\" --forcelock",
-                              lock, display);
-    }
-  else if ((lock = g_find_program_in_path("xscreensaver-command")))
-    {
-      xlock = g_strdup_printf("%s --display \"%s\" -lock",
-                              lock, display);
-    }
-  else if ((lock = g_find_program_in_path("xlock")))
-    {
-      xlock = g_strdup_printf("%s -display \"%s\"",
-                              lock, display);
-    }
-  else if ((lock = g_find_program_in_path("gnome-screensaver-command")))
-    {
-      xlock = g_strdup_printf("%s --lock", lock);
-    }
-  g_free(lock);
-  
-  if (xlock != NULL)
-    {
-      TRACE_MSG("Locking enabled: " << xlock);
+      g_free(program);
+      lock_display = display;
+      TRACE_MSG("Locking enabled");
     }
   else
     {
@@ -246,20 +298,20 @@ get_self_typed_prop (Display *display,
                      Window      xwindow,
                      Atom        atom,
                      unsigned long     *val)
-{  
+{
   Atom type;
   int format;
   unsigned long nitems;
   unsigned long bytes_after;
   unsigned long *num;
-  
+
   type = None;
   XGetWindowProperty (display,
                       xwindow,
                       atom,
                       0, 100000,
                       False, atom, &type, &format, &nitems,
-                      &bytes_after, (unsigned char **)&num);  
+                      &bytes_after, (unsigned char **)&num);
 
   if (type != atom) {
     return false;
@@ -267,7 +319,7 @@ get_self_typed_prop (Display *display,
 
   if (val)
     *val = *num;
-  
+
   XFree (num);
 
   return true;
@@ -285,26 +337,26 @@ static bool
 look_for_kdesktop_recursive (Display *display, Window xwindow)
 {
   Window ignored1, ignored2;
-  Window *children;
-  unsigned int n_children;
-  unsigned int i;
+  Window *children = NULL;
+  unsigned int n_children = 0;
+  unsigned int i = 0;
   bool retval;
-  
+
   /* If WM_STATE is set, this is a managed client, so look
    * for the class hint and end recursion. Otherwise,
    * this is probably just a WM frame, so keep recursing.
    */
-  if (has_wm_state (display, xwindow)) {      
+  if (has_wm_state (display, xwindow)) {
     XClassHint ch;
-      
+
     ch.res_name = NULL;
     ch.res_class = NULL;
-      
+
     XGetClassHint (display, xwindow, &ch);
-      
+
     if (ch.res_name)
       XFree (ch.res_name);
-      
+
     if (ch.res_class) {
       if (strcasecmp (ch.res_class, "kdesktop") == 0) {
         XFree (ch.res_class);
@@ -316,29 +368,30 @@ look_for_kdesktop_recursive (Display *display, Window xwindow)
     return false;
   }
   retval = false;
-  
-  XQueryTree (display,
-              xwindow,
-              &ignored1, &ignored2, &children, &n_children);
 
-  i = 0;
-  while (i < n_children) {
-    if (look_for_kdesktop_recursive (display, children[i])) {
-      retval = true;
-      break;
+  Status status = XQueryTree(display,
+                             xwindow,
+                             &ignored1, &ignored2, &children, &n_children);
+  if (status)
+    {
+      i = 0;
+      while (i < n_children) {
+        if (look_for_kdesktop_recursive (display, children[i])) {
+          retval = true;
+          break;
+        }
+
+        ++i;
+      }
+
+      if (children)
+        XFree (children);
     }
-      
-    ++i;
-  }
-  
-  if (children)
-    XFree (children);
 
   return retval;
 }
 
 
-
 void
 System::init_kde(const char *display)
 {
