@@ -1,19 +1,19 @@
 // PreferencesDialog.cc --- Preferences dialog
 //
-// Copyright (C) 2002, 2003, 2004, 2006 Raymond Penners <raymond@dotsphinx.com>
+// Copyright (C) 2002, 2003, 2004, 2006, 2007 Raymond Penners <raymond@dotsphinx.com>
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2, or (at your option)
 // any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-// $Id: PreferencesDialog.cc 1090 2006-10-01 20:49:47Z dotsphinx $
+// $Id: PreferencesDialog.cc 1325 2007-09-10 19:45:53Z rcaelers $
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -50,6 +50,8 @@
 #include "NetworkPreferencePage.hh"
 #endif
 
+// #include "PluginsPreferencePage.hh"
+
 
 PreferencesDialog::PreferencesDialog()
   : HigDialog(_("Preferences"), false, false)
@@ -61,7 +63,7 @@ PreferencesDialog::PreferencesDialog()
   Gtk::Widget *gui_general_page = manage(create_gui_page());
   Gtk::Notebook *gui_page = manage(new Gtk::Notebook());
   gui_page->append_page(*gui_general_page, _("General"));
-  
+
   Gtk::Widget *gui_mainwindow_page = manage(create_mainwindow_page());
   gui_page->append_page(*gui_mainwindow_page, _("Status Window"));
 
@@ -78,6 +80,11 @@ PreferencesDialog::PreferencesDialog()
 #ifdef HAVE_DISTRIBUTION
   add_page(_("Network"), "network.png", *network_page);
 #endif
+
+#if 0  
+  Gtk::Widget *plugins_page = manage( new PluginsPreferencePage() );
+  add_page( _("Plugins"), "workrave-icon-huge.png", *plugins_page );
+#endif
   
   // Dialog
   get_vbox()->pack_start(notebook, true, true, 0);
@@ -89,7 +96,7 @@ PreferencesDialog::PreferencesDialog()
 #ifdef HAVE_X
   GtkUtil::set_wmclass(*this, "Preferences");
 #endif
-  
+
   show_all();
 
   TRACE_EXIT();
@@ -134,13 +141,13 @@ PreferencesDialog::create_gui_page()
     }
   sound_button->set_history(idx);
   sound_button->signal_changed().connect(MEMBER_SLOT(*this, &PreferencesDialog::on_sound_changed));
-  
+
   // Tray start
 //   start_in_tray_cb
 //     = manage(new Gtk::CheckButton(_("Hide main window at start-up")));
 //   start_in_tray_cb->signal_toggled()
 //     .connect(MEMBER_SLOT(*this,
-// 			&PreferencesDialog::on_start_in_tray_toggled));
+//      &PreferencesDialog::on_start_in_tray_toggled));
 //   start_in_tray_cb->set_active(MainWindow::get_start_in_tray());
 
 
@@ -267,7 +274,7 @@ PreferencesDialog::on_block_changed()
     }
   GUI::get_instance()->set_block_mode(m);
 }
-  
+
 
 // void
 // PreferencesDialog::on_start_in_tray_toggled()
@@ -287,11 +294,16 @@ PreferencesDialog::run()
 
 bool
 PreferencesDialog::on_focus_in_event(GdkEventFocus *event)
-{ 
+{
   TRACE_ENTER("PreferencesDialog::focus_in");
 
   ICore *core = CoreFactory::get_core();
-  mode = core->set_operation_mode(OPERATION_MODE_QUIET);
+
+  mode = core->get_operation_mode();
+  if (mode == OPERATION_MODE_NORMAL)
+    {
+      mode = core->set_operation_mode(OPERATION_MODE_QUIET);
+    }
   TRACE_EXIT();
   return HigDialog::on_focus_in_event(event);
 }
@@ -299,9 +311,10 @@ PreferencesDialog::on_focus_in_event(GdkEventFocus *event)
 
 bool
 PreferencesDialog::on_focus_out_event(GdkEventFocus *event)
-{ 
+{
   TRACE_ENTER("PreferencesDialog::focus_out");
   ICore *core = CoreFactory::get_core();
+
   core->set_operation_mode(mode);
   TRACE_EXIT();
   return HigDialog::on_focus_out_event(event);
