@@ -1,6 +1,6 @@
 // RestBreakWindow.cc --- window for the microbreak
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 //
@@ -8,14 +8,14 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2, or (at your option)
 // any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: RestBreakWindow.cc 1109 2006-11-13 19:16:52Z rcaelers $";
+static const char rcsid[] = "$Id: RestBreakWindow.cc 1316 2007-09-08 17:40:55Z rcaelers $";
 
 const int TIMEOUT = 1000;
 
@@ -48,6 +48,7 @@ const int TIMEOUT = 1000;
 #include "Frame.hh"
 
 #include "ICore.hh"
+#include "IConfigurator.hh"
 #include "CoreFactory.hh"
 #include "IActivityMonitor.hh"
 
@@ -86,7 +87,7 @@ RestBreakWindow::create_gui()
 #ifdef HAVE_EXERCISES
   pluggable_panel = manage(new Gtk::HBox);
 #endif
-  
+
   vbox->pack_start(
 #ifdef HAVE_EXERCISES
                    *pluggable_panel
@@ -146,7 +147,7 @@ RestBreakWindow::start()
 //! Period timer callback.
 void
 RestBreakWindow::refresh()
-{ 
+{
   BreakWindow::refresh();
 
   draw_time_bar();
@@ -170,7 +171,7 @@ RestBreakWindow::draw_time_bar()
   time_t time = progress_max_value - progress_value;
   char s[128];
   sprintf(s, _("Rest break for %s"), Text::time_to_string(time, true).c_str());
-  
+
   timebar->set_text(s);
 
   ICore *core = CoreFactory::get_core();
@@ -192,7 +193,7 @@ RestBreakWindow::draw_time_bar()
           is_flashing = false;
         }
     }
-  
+
   timebar->update();
 }
 
@@ -201,7 +202,7 @@ Gtk::Widget *
 RestBreakWindow::create_info_panel()
 {
   Gtk::HBox *info_box = manage(new Gtk::HBox(false, 12));
-  
+
   string icon = Util::complete_directory("rest-break.png", Util::SEARCH_PATH_IMAGES);
   Gtk::Image *info_img = manage(new Gtk::Image(icon));
   info_img->set_alignment(0.0, 0.0);
@@ -236,12 +237,12 @@ int
 RestBreakWindow::get_exercise_count()
 {
   int ret = 0;
-  
+
   if (Exercise::has_exercises())
     {
       ICore *core = CoreFactory::get_core();
       assert(core != NULL);
-      
+
       ret = core->get_break(BREAK_ID_REST_BREAK)->get_break_exercises();
     }
   return ret;
@@ -287,7 +288,16 @@ RestBreakWindow::set_ignore_activity(bool i)
 {
   ICore *core = CoreFactory::get_core();
   assert(core != NULL);
-  
+
+#ifdef WIN32
+  bool force_focus = false;
+  CoreFactory::get_configurator()->get_value_default("advanced/force_focus", &force_focus, false);
+  if (force_focus)
+    {
+      i = true;
+    }
+#endif
+
   core->set_insist_policy(i ?
                         ICore::INSIST_POLICY_IGNORE :
                         (block_mode != GUI::BLOCK_MODE_NONE
