@@ -1,20 +1,20 @@
-// WindowHints.cc 
+// WindowHints.cc
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2, or (at your option)
 // any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: WindowHints.cc 927 2005-10-26 18:51:24Z rcaelers $";
+static const char rcsid[] = "$Id: WindowHints.cc 1298 2007-08-30 14:18:04Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -51,7 +51,7 @@ bool
 WindowHints::init()
 {
   bool rc = false;
-  
+
 #if defined(HAVE_X)
   type = HINTTYPE_NONE;
 
@@ -94,7 +94,7 @@ WindowHints::set_always_on_top(GtkWidget *window, bool onTop)
       //WmSpec::change_state(window, !onTop, "_NET_WM_STATE_BELOW");
       rc = true;
     }
-  
+
 #elif defined(WIN32)
   HWND hwnd = (HWND) GDK_WINDOW_HWND(window->window);
   W32Compat::SetWindowOnTop(hwnd, onTop);
@@ -121,7 +121,7 @@ WindowHints::set_skip_winlist(GtkWidget *window, bool skip)
           {
             wh |= (WIN_HINTS_SKIP_WINLIST | WIN_HINTS_SKIP_TASKBAR);
           }
-            
+
         gnome_win_hints_set_hints(window, (GnomeWinHints) wh);
       }
       ret = true;
@@ -130,7 +130,7 @@ WindowHints::set_skip_winlist(GtkWidget *window, bool skip)
       WmSpec::change_state(window, skip, "_NET_WM_STATE_SKIP_TASKBAR");
       WmSpec::change_state(window, skip, "_NET_WM_STATE_SKIP_PAGER");
       ret = true;
-      
+
     default:
       break;
     }
@@ -143,12 +143,13 @@ WindowHints::set_skip_winlist(GtkWidget *window, bool skip)
 
 #ifdef WIN32
 static void
-win32_block_input(BOOL block, HWND *unblocked_windows)
+win32_block_input(BOOL block)
 {
   if (block)
-    harpoon_block_input_except_for(unblocked_windows);
+      harpoon_block_input();
   else
-    harpoon_unblock_input();
+      harpoon_unblock_input();
+
   UINT uPreviousState;
   SystemParametersInfo(SPI_SETSCREENSAVERRUNNING, block, &uPreviousState, 0);
 }
@@ -163,11 +164,11 @@ WindowHints::grab(int num_windows, GdkWindow **windows)
   if (num_windows > 0)
     {
       // Only grab first window.
-      
+
       // Grab keyboard.
       GdkGrabStatus keybGrabStatus;
       keybGrabStatus = gdk_keyboard_grab(windows[0], TRUE, GDK_CURRENT_TIME);
-      
+
       // Grab pointer
       GdkGrabStatus pointerGrabStatus;
       pointerGrabStatus = gdk_pointer_grab(windows[0],
@@ -176,7 +177,7 @@ WindowHints::grab(int num_windows, GdkWindow **windows)
                                                            GDK_BUTTON_PRESS_MASK |
                                                            GDK_POINTER_MOTION_MASK),
                                            NULL, NULL, GDK_CURRENT_TIME);
-      
+
       if (pointerGrabStatus == GDK_GRAB_SUCCESS
           && keybGrabStatus == GDK_GRAB_SUCCESS)
         {
@@ -192,15 +193,14 @@ WindowHints::grab(int num_windows, GdkWindow **windows)
       for (int i = 0; i < num_windows; i++)
         {
           unblocked_windows[i] = (HWND) GDK_WINDOW_HWND(windows[i]);
-
           SetWindowPos(unblocked_windows[i], HWND_TOPMOST,
                        0, 0, 0, 0, SWP_NOMOVE|SWP_NOSIZE);
           BringWindowToTop(unblocked_windows[i]);
         }
 
       unblocked_windows[num_windows] = NULL;
-      
-      win32_block_input(TRUE, unblocked_windows);
+
+      win32_block_input(TRUE);
       handle = (WindowHints::Grab *) 0xdeadf00d;
     }
 #endif
@@ -214,13 +214,13 @@ WindowHints::ungrab(WindowHints::Grab *handle)
 {
   if (! handle)
     return;
-  
+
 #if defined(HAVE_X)
   gdk_keyboard_ungrab(GDK_CURRENT_TIME);
   gdk_pointer_ungrab(GDK_CURRENT_TIME);
 
 #elif defined(WIN32)
-  win32_block_input(FALSE, NULL);
+  win32_block_input(FALSE);
 #endif
 }
 
@@ -231,13 +231,13 @@ WindowHints::set_tool_window(GtkWidget *window, bool istool)
   bool rc = false;
 #if defined(HAVE_X)
   (void) istool;
-  
+
   switch (type)
     {
     case HINTTYPE_NET:
       WmSpec::set_window_hint(window, "_NET_WM_WINDOW_TYPE_UTILITY");
       rc = true;
-      
+
     default:
       break;
     }
@@ -264,15 +264,3 @@ WindowHints::set_tool_window(GtkWidget *window, bool istool)
 #endif
   return rc;
 }
-
-
-#if defined(WIN32)
-void
-WindowHints::attach_thread_input(bool enabled)
-{
-  AttachThreadInput
-    (GetWindowThreadProcessId(GetForegroundWindow(),NULL),
-     GetCurrentThreadId(),enabled);
-  
-}
-#endif
