@@ -1,19 +1,19 @@
 // ExercisesPanel.cc --- Exercises panel
 //
-// Copyright (C) 2002, 2003, 2004, 2006 Raymond Penners <raymond@dotsphinx.com>
+// Copyright (C) 2002, 2003, 2004, 2006, 2007 Raymond Penners <raymond@dotsphinx.com>
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2, or (at your option)
 // any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-// $Id: ExercisesPanel.cc 1109 2006-11-13 19:16:52Z rcaelers $
+// $Id: ExercisesPanel.cc 1298 2007-08-30 14:18:04Z rcaelers $
 //
 
 #include "config.h"
@@ -44,128 +44,128 @@ text_buffer_insert_markup_real (GtkTextBuffer *buffer,
                                 const gchar   *markup,
                                 gint           len)
 {
-	PangoAttrIterator  *paiter;
-	PangoAttrList      *attrlist;
-	GtkTextMark        *mark;
-	GError             *error = NULL;
-	gchar              *text;
+  PangoAttrIterator  *paiter;
+  PangoAttrList      *attrlist;
+  GtkTextMark        *mark;
+  GError             *error = NULL;
+  gchar              *text;
 
   g_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
   g_return_if_fail (textiter != NULL);
   g_return_if_fail (markup != NULL);
   g_return_if_fail (gtk_text_iter_get_buffer (textiter) == buffer);
 
-	if (len == 0)
-		return;
+  if (len == 0)
+    return;
 
-	if (!pango_parse_markup(markup, len, 0, &attrlist, &text, NULL, &error))
-	{
-		g_warning("Invalid markup string: %s", error->message);
-		g_error_free(error);
-		return;
-	}
+  if (!pango_parse_markup(markup, len, 0, &attrlist, &text, NULL, &error))
+  {
+    g_warning("Invalid markup string: %s", error->message);
+    g_error_free(error);
+    return;
+  }
 
-	len = strlen(text); /* TODO: is this needed? */
+  len = strlen(text); /* TODO: is this needed? */
 
-	if (attrlist == NULL)
-	{
-		gtk_text_buffer_insert(buffer, textiter, text, len);
-		g_free(text);
-		return;
-	}
+  if (attrlist == NULL)
+  {
+    gtk_text_buffer_insert(buffer, textiter, text, len);
+    g_free(text);
+    return;
+  }
 
-	/* create mark with right gravity */
-	mark = gtk_text_buffer_create_mark(buffer, NULL, textiter, FALSE);
+  /* create mark with right gravity */
+  mark = gtk_text_buffer_create_mark(buffer, NULL, textiter, FALSE);
 
-	paiter = pango_attr_list_get_iterator(attrlist);
+  paiter = pango_attr_list_get_iterator(attrlist);
 
-	do
-	{
-		PangoAttribute *attr;
-		GtkTextTag     *tag;
-		gint            start, end;
+  do
+  {
+    PangoAttribute *attr;
+    GtkTextTag     *tag;
+    gint            start, end;
 
-		pango_attr_iterator_range(paiter, &start, &end);
+    pango_attr_iterator_range(paiter, &start, &end);
 
-		if (end == G_MAXINT)  /* last chunk */
-			end = strlen(text);
+    if (end == G_MAXINT)  /* last chunk */
+      end = strlen(text);
 
-		tag = gtk_text_tag_new(NULL);
+    tag = gtk_text_tag_new(NULL);
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_LANGUAGE)))
-			g_object_set(tag, "language", pango_language_to_string(((PangoAttrLanguage*)attr)->value), NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_LANGUAGE)))
+      g_object_set(tag, "language", pango_language_to_string(((PangoAttrLanguage*)attr)->value), NULL);
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_FAMILY)))
-			g_object_set(tag, "family", ((PangoAttrString*)attr)->value, NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_FAMILY)))
+      g_object_set(tag, "family", ((PangoAttrString*)attr)->value, NULL);
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_STYLE)))
-			g_object_set(tag, "style", ((PangoAttrInt*)attr)->value, NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_STYLE)))
+      g_object_set(tag, "style", ((PangoAttrInt*)attr)->value, NULL);
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_WEIGHT)))
-			g_object_set(tag, "weight", ((PangoAttrInt*)attr)->value, NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_WEIGHT)))
+      g_object_set(tag, "weight", ((PangoAttrInt*)attr)->value, NULL);
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_VARIANT)))
-			g_object_set(tag, "variant", ((PangoAttrInt*)attr)->value, NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_VARIANT)))
+      g_object_set(tag, "variant", ((PangoAttrInt*)attr)->value, NULL);
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_STRETCH)))
-			g_object_set(tag, "stretch", ((PangoAttrInt*)attr)->value, NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_STRETCH)))
+      g_object_set(tag, "stretch", ((PangoAttrInt*)attr)->value, NULL);
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_SIZE)))
-			g_object_set(tag, "size", ((PangoAttrInt*)attr)->value, NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_SIZE)))
+      g_object_set(tag, "size", ((PangoAttrInt*)attr)->value, NULL);
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_FONT_DESC)))
-			g_object_set(tag, "font-desc", ((PangoAttrFontDesc*)attr)->desc, NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_FONT_DESC)))
+      g_object_set(tag, "font-desc", ((PangoAttrFontDesc*)attr)->desc, NULL);
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_FOREGROUND)))
-		{
-			GdkColor col = { 0,
-			                 ((PangoAttrColor*)attr)->color.red,
-			                 ((PangoAttrColor*)attr)->color.green,
-			                 ((PangoAttrColor*)attr)->color.blue
-			               };
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_FOREGROUND)))
+    {
+      GdkColor col = { 0,
+                       ((PangoAttrColor*)attr)->color.red,
+                       ((PangoAttrColor*)attr)->color.green,
+                       ((PangoAttrColor*)attr)->color.blue
+                     };
 
-			g_object_set(tag, "foreground-gdk", &col, NULL);
-		}
+      g_object_set(tag, "foreground-gdk", &col, NULL);
+    }
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_BACKGROUND)))
-		{
-			GdkColor col = { 0,
-			                 ((PangoAttrColor*)attr)->color.red,
-			                 ((PangoAttrColor*)attr)->color.green,
-			                 ((PangoAttrColor*)attr)->color.blue
-			               };
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_BACKGROUND)))
+    {
+      GdkColor col = { 0,
+                       ((PangoAttrColor*)attr)->color.red,
+                       ((PangoAttrColor*)attr)->color.green,
+                       ((PangoAttrColor*)attr)->color.blue
+                     };
 
-			g_object_set(tag, "background-gdk", &col, NULL);
-		}
+      g_object_set(tag, "background-gdk", &col, NULL);
+    }
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_UNDERLINE)))
-			g_object_set(tag, "underline", ((PangoAttrInt*)attr)->value, NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_UNDERLINE)))
+      g_object_set(tag, "underline", ((PangoAttrInt*)attr)->value, NULL);
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_STRIKETHROUGH)))
-			g_object_set(tag, "strikethrough", (gboolean)(((PangoAttrInt*)attr)->value != 0), NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_STRIKETHROUGH)))
+      g_object_set(tag, "strikethrough", (gboolean)(((PangoAttrInt*)attr)->value != 0), NULL);
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_RISE)))
-			g_object_set(tag, "rise", ((PangoAttrInt*)attr)->value, NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_RISE)))
+      g_object_set(tag, "rise", ((PangoAttrInt*)attr)->value, NULL);
 
-		/* PANGO_ATTR_SHAPE cannot be defined via markup text */
+    /* PANGO_ATTR_SHAPE cannot be defined via markup text */
 
-		if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_SCALE)))
-			g_object_set(tag, "scale", ((PangoAttrFloat*)attr)->value, NULL);
+    if ((attr = pango_attr_iterator_get(paiter, PANGO_ATTR_SCALE)))
+      g_object_set(tag, "scale", ((PangoAttrFloat*)attr)->value, NULL);
 
-		gtk_text_tag_table_add(gtk_text_buffer_get_tag_table(buffer), tag);
+    gtk_text_tag_table_add(gtk_text_buffer_get_tag_table(buffer), tag);
 
-        	gtk_text_buffer_insert_with_tags(buffer, textiter, text+start, end - start, tag, NULL);
+          gtk_text_buffer_insert_with_tags(buffer, textiter, text+start, end - start, tag, NULL);
 
-		/* mark had right gravity, so it should be
-		 *  at the end of the inserted text now */
-		gtk_text_buffer_get_iter_at_mark(buffer, textiter, mark);
-	}
-	while (pango_attr_iterator_next(paiter));
+    /* mark had right gravity, so it should be
+     *  at the end of the inserted text now */
+    gtk_text_buffer_get_iter_at_mark(buffer, textiter, mark);
+  }
+  while (pango_attr_iterator_next(paiter));
 
-	gtk_text_buffer_delete_mark(buffer, mark);
-	pango_attr_iterator_destroy(paiter);
-	pango_attr_list_unref(attrlist);
-	g_free(text);
+  gtk_text_buffer_delete_mark(buffer, mark);
+  pango_attr_iterator_destroy(paiter);
+  pango_attr_list_unref(attrlist);
+  g_free(text);
 }
 
 static void
@@ -184,23 +184,23 @@ text_buffer_set_markup (GtkTextBuffer *buffer,
                         const gchar   *markup,
                         gint           len)
 {
-	GtkTextIter start, end;
+  GtkTextIter start, end;
 
-	g_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
-	g_return_if_fail (markup != NULL);
+  g_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
+  g_return_if_fail (markup != NULL);
 
-	if (len < 0)
-		len = strlen (markup);
+  if (len < 0)
+    len = strlen (markup);
 
-	gtk_text_buffer_get_bounds (buffer, &start, &end);
+  gtk_text_buffer_get_bounds (buffer, &start, &end);
 
-	gtk_text_buffer_delete (buffer, &start, &end);
+  gtk_text_buffer_delete (buffer, &start, &end);
 
-	if (len > 0)
-	{
-		gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
-		text_buffer_insert_markup (buffer, &start, markup, len);
-	}
+  if (len > 0)
+  {
+    gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
+    text_buffer_insert_markup (buffer, &start, markup, len);
+  }
 }
 // (end code to be removed)
 
@@ -211,7 +211,7 @@ ExercisesPanel::ExercisesPanel(Gtk::HButtonBox *dialog_action_area)
          exercises(Exercise::get_exercises())
 {
   standalone = dialog_action_area != NULL;
-  
+
   progress_bar.set_orientation(Gtk::PROGRESS_BOTTOM_TO_TOP);
 
   description_scroll.add(description_text);
@@ -224,12 +224,12 @@ ExercisesPanel::ExercisesPanel(Gtk::HButtonBox *dialog_action_area)
 
   pause_button =  manage(new Gtk::Button());
   Gtk::Widget *description_widget;
-  
+
   if (dialog_action_area != NULL)
     {
       back_button =  manage(new Gtk::Button(Gtk::Stock::GO_BACK));
       forward_button =  manage(new Gtk::Button(Gtk::Stock::GO_FORWARD));
-      
+
       dialog_action_area->pack_start(*back_button, false, false, 0);
       dialog_action_area->pack_start(*pause_button, false, false, 0);
       dialog_action_area->pack_start(*forward_button, false, false, 0);
@@ -241,8 +241,8 @@ ExercisesPanel::ExercisesPanel(Gtk::HButtonBox *dialog_action_area)
                            (NULL, Gtk::Stock::GO_BACK));
       forward_button =  manage(GtkUtil::create_custom_stock_button
                                (NULL, Gtk::Stock::GO_FORWARD));
-      
-      Gtk::Button *stop_button =  manage(GtkUtil::create_custom_stock_button
+
+      stop_button =  manage(GtkUtil::create_custom_stock_button
                                          (NULL, Gtk::Stock::CLOSE));
       stop_button->signal_clicked()
         .connect(MEMBER_SLOT(*this, &ExercisesPanel::on_stop));
@@ -284,7 +284,15 @@ ExercisesPanel::ExercisesPanel(Gtk::HButtonBox *dialog_action_area)
   pause_button->signal_clicked()
     .connect(MEMBER_SLOT(*this, &ExercisesPanel::on_pause));
 
-  
+#ifdef FIXME // Causes fuzzy translations...
+  tooltips = manage( new Gtk::Tooltips() );
+  tooltips->set_tip( *back_button, _("Previous exercise") );
+  tooltips->set_tip( *forward_button, _("Next exercise") );
+  tooltips->set_tip( *pause_button, _("Pause exercises") );
+  tooltips->set_tip( *stop_button, _("End exercises") );
+  tooltips->enable();
+#endif
+
   pack_start(image_frame, false, false, 0);
   pack_start(progress_bar, false, false, 0);
   pack_start(*description_widget, false, false, 0);
@@ -303,7 +311,7 @@ ExercisesPanel::on_realize()
   Gtk::HBox::on_realize();
   description_text.modify_base
     (Gtk::STATE_NORMAL, get_style()->get_background(Gtk::STATE_NORMAL));
-} 
+}
 
 
 ExercisesPanel::~ExercisesPanel()
@@ -447,6 +455,12 @@ ExercisesPanel::refresh_pause()
   GtkUtil::update_custom_stock_button(pause_button,
                                       standalone ? label : NULL,
                                       stock_id);
+#ifdef FIXME // Causes fuzzy translations...
+  if (paused)
+    tooltips->set_tip( *pause_button, _("Resume exercises"));
+  else
+    tooltips->set_tip( *pause_button, _("Pause exercises"));
+#endif
 }
 
 void
@@ -464,7 +478,7 @@ ExercisesPanel::heartbeat()
 
   if (exercises.size() == 0)
     return;
-  
+
   const Exercise &exercise = *exercise_iterator;
   exercise_time++;
   if (exercise_time >= exercise.duration)
